class doc:

    def __init__(self):
        """Explain what the 'doc' class does."""
        print("The 'doc' class provides useful resources, documentation links, and tutorials for popular libraries in various fields.")
        print("Use methods like 'doc.ai()' or 'doc.web()' to get resources for specific fields.")
    
    
    @staticmethod
    def ai():
        print("AI Resources:")
        print("- TensorFlow Documentation: https://www.tensorflow.org/")
        print("- PyTorch Documentation: https://pytorch.org/docs/")
        print("- Keras Documentation: https://keras.io/")
        print("- Scikit-learn Documentation: https://scikit-learn.org/stable/")
        print("- MXNet Documentation: https://mxnet.apache.org/")
        print("- XGBoost Documentation: https://xgboost.readthedocs.io/")
        print("- LightGBM Documentation: https://lightgbm.readthedocs.io/")
        print("- CatBoost Documentation: https://catboost.ai/")
        print("- CNTK Documentation: https://docs.microsoft.com/en-us/cognitive-toolkit/")
        print("- Dlib Documentation: http://dlib.net/")

    @staticmethod
    def computer_vision():
        print("Computer Vision Resources:")
        print("- OpenCV Documentation: https://docs.opencv.org/")
        print("- TensorFlow Documentation: https://www.tensorflow.org/")
        print("- PyTorch Vision Documentation: https://pytorch.org/vision/stable/index.html")
        print("- Mediapipe Documentation: https://google.github.io/mediapipe/")
        print("- Dlib Documentation: http://dlib.net/")
        print("- Detectron2 Documentation: https://detectron2.readthedocs.io/")
        print("- ImageAI Documentation: https://github.com/OlafenwaMoses/ImageAI")
        print("- Albumentations Documentation: https://albumentations.ai/docs/")
        print("- SimpleCV Documentation: http://simplecv.org/")
        print("- MMCV Documentation: https://mmcv.readthedocs.io/")

    @staticmethod
    def nlp():
        print("NLP Resources:")
        print("- NLTK Documentation: https://www.nltk.org/")
        print("- SpaCy Documentation: https://spacy.io/")
        print("- HuggingFace Transformers Documentation: https://huggingface.co/transformers/")
        print("- Gensim Documentation: https://radimrehurek.com/gensim/")
        print("- Flair Documentation: https://github.com/flairNLP/flair")
        print("- FastText Documentation: https://fasttext.cc/docs/en/python-module.html")
        print("- Stanford NLP Documentation: https://stanfordnlp.github.io/CoreNLP/")
        print("- Polyglot Documentation: https://polyglot.readthedocs.io/")
        print("- PyTorch-NLP Documentation: https://pytorchnlp.readthedocs.io/en/latest/")
        print("- TextBlob Documentation: https://textblob.readthedocs.io/")

    @staticmethod
    def web():
        print("Web Development Resources:")
        print("- Django Documentation: https://docs.djangoproject.com/")
        print("- Flask Documentation: https://flask.palletsprojects.com/")
        print("- FastAPI Documentation: https://fastapi.tiangolo.com/")
        print("- Requests Documentation: https://docs.python-requests.org/")
        print("- Bottle Documentation: https://bottlepy.org/docs/dev/")
        print("- Tornado Documentation: https://www.tornadoweb.org/en/stable/")
        print("- Pyramid Documentation: https://trypyramid.com/")
        print("- Aiohttp Documentation: https://docs.aiohttp.org/")
        print("- Dash Documentation: https://dash.plotly.com/")
        print("- Sanic Documentation: https://sanicframework.org/")

    @staticmethod
    def data():
        print("Data Processing Resources:")
        print("- Pandas Documentation: https://pandas.pydata.org/")
        print("- NumPy Documentation: https://numpy.org/")
        print("- Matplotlib Documentation: https://matplotlib.org/")
        print("- Seaborn Documentation: https://seaborn.pydata.org/")
        print("- Plotly Documentation: https://plotly.com/python/")
        print("- Dask Documentation: https://dask.org/")
        print("- PyArrow Documentation: https://arrow.apache.org/docs/")
        print("- Polars Documentation: https://pola-rs.github.io/polars-book/")
        print("- H5Py Documentation: https://www.h5py.org/")
        print("- Vaex Documentation: https://vaex.io/")

    @staticmethod
    def embedded():
        print("Embedded Systems Resources:")
        print("- MicroPython Documentation: https://docs.micropython.org/")
        print("- CircuitPython Documentation: https://circuitpython.readthedocs.io/")
        print("- RPi.GPIO Documentation: https://sourceforge.net/p/raspberry-gpio-python/wiki/Home/")
        print("- PySerial Documentation: https://pyserial.readthedocs.io/")
        print("- MRAA Documentation: https://iotdk.intel.com/docs/master/mraa/")
        print("- UPM Documentation: https://iotdk.intel.com/docs/master/upm/")
        print("- Pyb Documentation: https://docs.micropython.org/en/latest/library/pyb.html")
        print("- PiCamera Documentation: https://picamera.readthedocs.io/")
        print("- GPIOZero Documentation: https://gpiozero.readthedocs.io/")
        print("- Micro:bit Documentation: https://microbit-micropython.readthedocs.io/")

    @staticmethod
    def os():
        print("Operating Systems Resources:")
        print("- OS Module Documentation: https://docs.python.org/3/library/os.html")
        print("- Psutil Documentation: https://psutil.readthedocs.io/")
        print("- Subprocess Module Documentation: https://docs.python.org/3/library/subprocess.html")
        print("- Pathlib Documentation: https://docs.python.org/3/library/pathlib.html")
        print("- Shutil Documentation: https://docs.python.org/3/library/shutil.html")
        print("- Click Documentation: https://click.palletsprojects.com/")
        print("- Watchdog Documentation: https://pythonhosted.org/watchdog/")
        print("- Pexpect Documentation: https://pexpect.readthedocs.io/")
        print("- PyAutoGUI Documentation: https://pyautogui.readthedocs.io/")
        print("- Path Documentation: https://path.readthedocs.io/")

    @staticmethod
    def math():
        print("Math Resources:")
        print("- Math Module Documentation: https://docs.python.org/3/library/math.html")
        print("- SymPy Documentation: https://docs.sympy.org/")
        print("- SciPy Documentation: https://scipy.org/")
        print("- Statistics Module Documentation: https://docs.python.org/3/library/statistics.html")
        print("- Random Module Documentation: https://docs.python.org/3/library/random.html")
        print("- MPMath Documentation: https://mpmath.org/")
        print("- NumExpr Documentation: https://numexpr.readthedocs.io/")
        print("- PyMC3 Documentation: https://docs.pymc.io/")
        print("- CVXPY Documentation: https://www.cvxpy.org/")
        print("- NetworkX Documentation: https://networkx.github.io/")

    @staticmethod
    def robotics():
        print("Robotics Resources:")
        print("- ROS Documentation: https://www.ros.org/")
        print("- PyRobot Documentation: https://pyrobot.org/")
        print("- PyBullet Documentation: https://pybullet.org/")
        print("- URX Documentation: https://github.com/SintefRaufossManufacturing/urx")
        print("- RobotFramework Documentation: https://robotframework.org/")
        print("- RoboSuite Documentation: https://robosuite.ai/")
        print("- OpenAI Gym Documentation: https://gym.openai.com/")
        print("- MoveIt Documentation: https://moveit.ros.org/")
        print("- Webots Documentation: https://cyberbotics.com/doc/guide/")
        print("- VPython Documentation: https://vpython.org/")

    @staticmethod
    def networking():
        print("Networking Resources:")
        print("- Socket Module Documentation: https://docs.python.org/3/library/socket.html")
        print("- Paramiko Documentation: http://docs.paramiko.org/")
        print("- Scapy Documentation: https://scapy.readthedocs.io/")
        print("- Requests Documentation: https://docs.python-requests.org/")
        print("- Asyncio Documentation: https://docs.python.org/3/library/asyncio.html")
        print("- Twisted Documentation: https://twistedmatrix.com/documents/current/")
        print("- PyShark Documentation: https://github.com/KimiNewt/pyshark")
        print("- FTPLib Documentation: https://docs.python.org/3/library/ftplib.html")
        print("- DNSPython Documentation: http://www.dnspython.org/")
        print("- SocketIO Documentation: https://python-socketio.readthedocs.io/")

    @staticmethod
    def database():
        print("Database Resources:")
        print("- SQLAlchemy Documentation: https://www.sqlalchemy.org/")
        print("- PyMongo Documentation: https://pymongo.readthedocs.io/")
        print("- Redis-Py Documentation: https://redis-py.readthedocs.io/")
        print("- Psycopg2 Documentation: https://www.psycopg.org/docs/")
        print("- SQLite3 Documentation: https://docs.python.org/3/library/sqlite3.html")
        print("- MySQL Connector Documentation: https://dev.mysql.com/doc/connector-python/en/")
        print("- Peewee Documentation: http://docs.peewee-orm.com/")
        print("- Pony ORM Documentation: https://docs.ponyorm.org/")
        print("- Dataset Documentation: https://dataset.readthedocs.io/")
        print("- Elasticsearch-Py Documentation: https://elasticsearch-py.readthedocs.io/")

    @staticmethod
    def security():
        print("Security Resources:")
        print("- Cryptography Documentation: https://cryptography.io/")
        print("- Paramiko Documentation: http://docs.paramiko.org/")
        print("- PyOpenSSL Documentation: https://pyopenssl.readthedocs.io/")
        print("- Hashlib Documentation: https://docs.python.org/3/library/hashlib.html")
        print("- Python-Nmap Documentation: https://pypi.org/project/python-nmap/")
        print("- Requests-NTLM Documentation: https://github.com/requests/requests-ntlm")
        print("- PassLib Documentation: https://passlib.readthedocs.io/")
        print("- PyCryptodome Documentation: https://pycryptodome.readthedocs.io/")
        print("- PyLibNaCl Documentation: https://pylibnacl.readthedocs.io/")
        print("- PyJWT Documentation: https://pyjwt.readthedocs.io/")
