# tests/test_doc.py
import sys
import os

# Add the parent directory to the system path
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

from Tmsa7.core.doc import *





doc.ai()

doc()