from setuptools import setup, find_packages

setup(
    name='Tmsa7',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'numpy',  # List your dependencies here
    ],
)
